@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmActionForm.php,v 1.4 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmActionForm.php,v 1.5 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_ActionForm.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmActionForm.php,v 1.4 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmActionForm.php,v 1.5 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmActionForm extends SyL_ActionForm
@@ -232,12 +232,8 @@ class SyL_AdmActionForm extends SyL_ActionForm
                 $this->elements_config[$name]['note'] = '';
             }
 
-            $type         = $values['type'];
-            $display_name = isset($values['name'])       ? $values['name']       : $name;
-            $options      = isset($values['options'])    ? $values['options']    : array();
-            $attributes   = isset($values['attributes']) ? $values['attributes'] : array();
             // Ǻ
-            $element =& $this->createElement($type, $name, $display_name, $options, $attributes);
+            $element =& $this->createElement($name, $values);
             // Ƚ
             if ($init && isset($values['default']) && ($this->type == 'new')) {
                 $element->setValue($values['default']);
@@ -250,12 +246,7 @@ class SyL_AdmActionForm extends SyL_ActionForm
                     $element->setReadOnly(true);
                 } else {
                     // Хǡɲ
-                    $vs =& SyL_Validators::create();
-                    foreach ($values['validate'] as $v_name => $v_values) {
-                        $v_parameters = isset($v_values['parameters']) ? $v_values['parameters'] : array();
-                        $vs->add(SyL_Validator::create($v_name, $v_values['message'], $v_parameters));
-                    }
-                    $element->setValidators($vs);
+                    $this->setElementValidations($element, $values);
                 }
             }
 
@@ -290,20 +281,16 @@ class SyL_AdmActionForm extends SyL_ActionForm
         if ($this->getStructConfig('enable_sch')) {
             // Ͽ롼
             foreach ($this->elements_config as $name => $values) {
-                // ǥɽ
-                if (isset($this->elements_config[$name]['note'])) {
-                    $this->elements_config[$name]['note'] = '';
-                }
-                $type         = $values['type'];
-                $display_name = isset($values['name'])       ? $values['name']       : $name;
-                $options      = isset($values['options'])    ? $values['options']    : array();
-                $attributes   = isset($values['attributes']) ? $values['attributes'] : array();
                 // Ǻ
-                $element =& $this->createElement($type, $name, $display_name, $options, $attributes);
+                $element =& $this->createElement($name, $values);
                 $this->addElement($element);
 
                 $this->elements_config_etc[$name]['cols']    = '1'; // ϶Ū2
                 $this->elements_config_etc[$name]['display'] = (isset($values['search']) && $values['search']);
+                // ǥɽ
+                if (isset($this->elements_config[$name]['note'])) {
+                    $this->elements_config[$name]['note'] = '';
+                }
             }
         }
     }
