@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.19 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.20 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.19 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.20 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigDefines extends SyL_Config
@@ -91,8 +91,9 @@ class SyL_ConfigDefines extends SyL_Config
      *
      * @access public
      * @param bool åͭե饰
+     * @param bool Ѵե饰
      */
-    function parseXml($enable_cache=true)
+    function parseXml($enable_cache=true, $change_constants=true)
     {
         if (SYL_CACHE && $enable_cache) {
             // åѤ
@@ -110,7 +111,9 @@ class SyL_ConfigDefines extends SyL_Config
         }
 
         // Ѵ
-        $this->readConstants();
+        if ($change_constants) {
+            $this->readConstants();
+        }
     }
 
     /**
