@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.21 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.22 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.21 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.22 2008/09/11 13:06:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigFilters extends SyL_Config
@@ -121,18 +121,20 @@ class SyL_ConfigFilters extends SyL_Config
      */
     function parseXml($enable_cache=true)
     {
-        if (SYL_CACHE && $enable_cache) {
-            // åѤ
-            $key = SYL_APP_DIR . $this->context->getActionFile();
-            $cache =& $this->getCache($key);
-            if ($cache) {
-                // å夬Ǥʤäʥå奪֥Ȥ
+        if (count($this->file_names) > 0) {
+            if (SYL_CACHE && $enable_cache) {
+                // åѤ
+                $key = SYL_APP_DIR . $this->context->getActionFile();
+                $cache =& $this->getCache($key);
+                if ($cache) {
+                    // å夬Ǥʤäʥå奪֥Ȥ
+                    parent::parseXml();
+                    $cache->write($this->config);
+                }
+            } else {
+                // åѤʤ
                 parent::parseXml();
-                $cache->write($this->config);
             }
-        } else {
-            // åѤʤ
-            parent::parseXml();
         }
     }
 
