@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.11 2008/09/23 09:06:16 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.12 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_ContextJs.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.11 2008/09/23 09:06:16 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.12 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextWeb extends SyL_ContextJs
@@ -127,7 +127,7 @@ class SyL_ContextWeb extends SyL_ContextJs
      */
     function getTemplateDir()
     {
-        return $this->template_dir;
+        return $this->template_dir . '/';
     }
 
     /**
@@ -139,7 +139,7 @@ class SyL_ContextWeb extends SyL_ContextJs
      */
     function getTemplateFile($trigger_error_404=true)
     {
-        $template_dir  = $this->template_dir . '/';
+        $template_dir  = $this->getTemplateDir();
         $template_file = $this->template_file;
         if (preg_match('/^(\\\\|\/)(.+)$/', $template_file, $matches)) {
             $template_file = $matches[2];
