@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorJs.php,v 1.10 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorJs.php,v 1.11 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorJs.php,v 1.10 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorJs.php,v 1.11 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorJs extends SyL_Error
@@ -51,7 +51,8 @@ class SyL_ErrorJs extends SyL_Error
      */
     function forward404Detail()
     {
-        SyL_Loggers::notice("404 Not Found");
+        $referer = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '(none)';
+        SyL_Loggers::warn("404 Not Found. from {$referer}");
 
         $error_message = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '';
         if (isset($_SERVER['REQUEST_METHOD']) && ($_SERVER['REQUEST_METHOD'] == 'POST')) {
