@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.8 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.9 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.8 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.9 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorXmlrpc extends SyL_Error
@@ -51,9 +51,10 @@ class SyL_ErrorXmlrpc extends SyL_Error
      */
     function forward404Detail()
     {
-        SyL_Loggers::notice("404 Not Found");
+        $referer = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '(none)';
+        SyL_Loggers::warn("404 Not Found. from {$referer}");
         SyL_Response::setStatusHeader('404');
-        
+
         echo "404 Not Found";
     }
 
