@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.29 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.30 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.29 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.30 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -70,15 +70,6 @@ class SyL_Container
      * @var array
      */
     var $components = array();
-    /**
-     * ݡͥȥ֥ȥ᥽åͳǼ
-     * ᥽åɥ󥸥η̤Τ
-     * ʣƱ᥽åɤƤӽФϺǸη̤Τ߼ǽ
-     * 
-     * @access private
-     * @var array
-     */
-    var $component_returns = array();
 
     /**
      * 󥹥ȥ饯
@@ -273,7 +264,7 @@ echo "</pre>";
                     $component =& $this->getComponent($name);
                     $method_name = $name . '.' . $funcs[1];
                     if (method_exists($component, $funcs[1])) {
-                        $this->component_returns[$method_name] = call_user_func_array(array(&$component, $funcs[1]), $value_args);
+                        call_user_func_array(array(&$component, $funcs[1]), $value_args);
                     } else {
                         // ͽʤ᥽åɤμ¹Ԥϥ顼
                         if (class_exists('SyL_Response')) {
@@ -479,19 +470,6 @@ echo "</pre>";
         unset($this->components[$name]);
     }
 
-    /**
-     * ݡͥȥ᥽åɤη̤
-     * ʣƱ᥽åɤƤӽФϺǸη̤Τ߼ǽ
-     *
-     * @access public
-     * @param string ݡͥ̾ + '.' + ᥽å̾
-     * @return string ݡͥȥ᥽åɤη
-     */
-    function getComponentMethodResult($name)
-    {
-        return $this->component_returns[$name];
-    }
-
     /**
      * ¸
      *
