@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.36 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.37 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -64,25 +64,11 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Container.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.36 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.37 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
 {
-    /**
-     * ǥ쥯ȥ롼
-     *
-     * @access private
-     * @var string
-     */
-    var $action_dir = '';
-    /**
-     * ƥץ졼ȥǥ쥯ȥ롼
-     *
-     * @access private
-     * @var string
-     */
-    var $template_dir = '';
     /**
      * 顼ϥɥ᥽å̾
      * ''ξϥ顼ϥɥꤷʤ
@@ -129,7 +115,7 @@ class SyL_Controller
     /**
      * 󥹥ȥ饯
      *
-     * @access public
+     * @access protected
      * @param array Ķ
      */
     function SyL_Controller($config)
@@ -183,11 +169,6 @@ class SyL_Controller
         // ɤ߹
         SyL_Config::get();
 
-        // ǥ쥯ȥ
-        $this->action_dir = SYL_APP_DIR . '/actions';
-        // ƥץ졼ȥǥ쥯ȥ
-        $this->template_dir = SYL_APP_DIR . '/templates';
-
         // ƥ
         $this->container =& SyL_Container::singleton();
         $this->container->setComponent('controller', $this);
@@ -199,45 +180,29 @@ class SyL_Controller
     }
 
     /**
-     * ȥ
-     *
-     * ¹ԴĶˤꡢWEB or CmdΥȥȽꤷƼ
+     * ȥݥ
      *
+     * @static
      * @access public
      * @param array Ķ
      */
-    function &getController($config=array())
+    function streaming($config)
     {
-        static $singleton;
-        if (!is_object($singleton)) {
-            if (isset($config['type']) && $config['type']) {
-                define('SYL_ENV_TYPE', strtolower($config['type']));
+        if (isset($config['type']) && $config['type']) {
+            define('SYL_ENV_TYPE', strtolower($config['type']));
+        } else {
+            if ((PHP_SAPI == 'cgi') && !isset($_SERVER['REQUEST_METHOD'])) {
+                trigger_error("[SyL error] Command line SAPI is CLI only", E_USER_ERROR);
+            } else if (PHP_SAPI == 'cli') {
+                define('SYL_ENV_TYPE', 'cmd');
             } else {
-                if ((PHP_SAPI == 'cgi') && !isset($_SERVER['REQUEST_METHOD'])) {
-                    trigger_error("[SyL error] Command line SAPI is CLI only", E_USER_ERROR);
-                } else if (PHP_SAPI == 'cli') {
-                    define('SYL_ENV_TYPE', 'cmd');
-                } else {
-                    define('SYL_ENV_TYPE', 'web');
-                }
+                define('SYL_ENV_TYPE', 'web');
             }
-            $class_name = 'SyL_Controller' . ucfirst(SYL_ENV_TYPE);
-            include_once SYL_INCLUDE_DIR . "/framework/Controller/{$class_name}.php";
-            // ҥ饹Υ󥹥
-            $singleton = new $class_name($config);
         }
-        return $singleton;
-    }
-
-    /**
-     * ƥʤ
-     *
-     * @access public
-     * @return object ƥʥ֥
-     */
-    function &getContainer()
-    {
-        return $this->container;
+        $class_name = 'SyL_Controller' . ucfirst(SYL_ENV_TYPE);
+        include_once SYL_INCLUDE_DIR . "/framework/Controller/{$class_name}.php";
+        $singleton = new $class_name($config);
+        $singleton->stream();
     }
 
     /**
@@ -406,9 +371,9 @@ class SyL_Controller
     }
 
     /**
-     * ȥݥ
+     * ¹ԴĶȤΥե
      *
-     * @access public
+     * @access abstract
      */
     function stream()
     {
