@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.21 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.22 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.21 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.22 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
@@ -124,21 +124,20 @@ class SyL_Router
      *
      * @static
      * @access public
-     * @param object ǡ֥
-     * @param string ܾ󥪥֥̾
      * @return object ܾ󥪥֥
      */
-    function &factory(&$data, $rule)
+    function &singleton()
     {
-        $classname = 'SyL_Router' . ucfirst($rule);
-        include_once SYL_INCLUDE_DIR . "/framework/Router/{$classname}.php";
-        $router =& new $classname();
-        $router->createActionInfo($data);
-        // եѥå
-        if (!$router->validAction()) {
-            SyL_Response::forward404();
+        static $router = null;
+        if ($router === null) {
+            $classname = 'SyL_Router' . ucfirst(SYL_ROUTER_RULE);
+            include_once SYL_INCLUDE_DIR . "/framework/Router/{$classname}.php";
+            $router = new $classname();
+            // եѥå
+            if (!$router->validAction()) {
+                SyL_Response::forward404();
+            }
         }
-        $router->changeRoutingConfig();
         return $router;
     }
 
@@ -150,7 +149,7 @@ class SyL_Router
      * $this->action_class
      *
      * @access protected
-     * @param object ꥯȥ֥
+     * @param object ǡ֥
      */
     function createActionInfo(&$data)
     {
@@ -225,9 +224,7 @@ class SyL_Router
     /**
      * 롼ƥŬ
      *
-     * @access protected
-     * @param object ƥȥ֥
-     * @param object ǡ֥
+     * @access public
      */
     function changeRoutingConfig()
     {
