@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.11 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.12 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_SMARTY_DIR . 'Smarty.class.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.11 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.12 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayoutSmarty extends SyL_ViewLayout
@@ -70,8 +70,8 @@ class SyL_ViewLayoutSmarty extends SyL_ViewLayout
         parent::SyL_ViewLayout($context, $data);
 
         $this->smarty =& new Smarty();
-        if (SYL_SMARTY_PROPERTIES) {
-            foreach(explode(';', SYL_SMARTY_PROPERTIES) as $properties) {
+        if (SYL_SMARTY_PARAMETER) {
+            foreach(explode(';', SYL_SMARTY_PARAMETER) as $properties) {
                 $tmp = explode('=', $properties, 2);
                 if (count($tmp) == 2) {
                     list($name, $value) = $tmp;
