@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.25 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.26 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'DB/SyL_DBSchema.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.25 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.26 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -201,10 +201,11 @@ class SyL_DB
             $type = ucfirst($tmp[0]);
             $dbtype = $dbname = $user = $passwd = $host = $port = $persistent = $client_encode = null;
             if (isset($tmp[1])) {
-                $tmp = explode(';', $tmp[1]);
-                foreach ($tmp as $tmp2) {
-                    list($name, $value) = explode('=', $tmp2, 2);
-                    $$name = $value;
+                foreach (explode(';', $tmp[1]) as $tmp2) {
+                    if (strpos($tmp2, '=') !== false) {
+                        list($name, $value) = explode('=', $tmp2, 2);
+                        $$name = $value;
+                    }
                 }
             }
 
