@@ -27,11 +27,13 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Filesystem.php,v 1.4 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Filesystem.php,v 1.5 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
+clearstatcache();
+
 /**
  * t@CVXẽfBNgNX
  */
@@ -52,7 +54,7 @@ require_once dirname(__FILE__) . '/Util/SyL_UtilEnv.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Filesystem.php,v 1.4 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Filesystem.php,v 1.5 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Filesystem
@@ -63,7 +65,7 @@ class SyL_Filesystem
      * @access protected
      * @var string
      */
-    var $name = '';
+    var $file = '';
     /**
      * vf^Cv
      *
@@ -85,17 +87,17 @@ class SyL_Filesystem
      * @access public
      * @param string vfi΃pXj
      */
-    function SyL_Filesystem($name)
+    function SyL_Filesystem($file)
     {
-        if (preg_match('/^(.+)(\\\\|\/)$/', $name)) {
-            $name = substr($name, 0, -1);
+        if (preg_match('/^(.+)(\\\\|\/)$/', $file)) {
+            $file = substr($file, 0, -1);
         }
         // t@CZbg
-        $this->name = $name;
+        $this->file = $file;
         // t@C^Cv
-        $this->type = filetype($name);
+        $this->type = filetype($file);
         // vf擾
-        $this->getStats();
+        $this->stat = stat($file);
     }
 
     /**
@@ -111,7 +113,6 @@ class SyL_Filesystem
             trigger_error("[SyL error] File not found ({$file})", E_USER_ERROR);
         }
 
-        clearstatcache();
         $file = realpath($file);
 
         $element = null;
@@ -126,12 +127,11 @@ class SyL_Filesystem
     /**
      * fBNg
      *
-     * @access public
+     * @access abstract
      * @return bool true: fBNgAfalse: fBNgȊO
      */
     function isDir()
     {
-        return false;
     }
 
     /**
@@ -142,7 +142,7 @@ class SyL_Filesystem
      */
     function isWritable()
     {
-        return is_writable($this->name);
+        return is_writable($this->file);
     }
 
     /**
@@ -154,7 +154,7 @@ class SyL_Filesystem
      */
     function getName($name_only=false)
     {
-        return ($name_only) ? basename($this->name) : $this->name;
+        return ($name_only) ? basename($this->file) : $this->file;
     }
 
     /**
@@ -180,36 +180,6 @@ class SyL_Filesystem
         return isset($this->stat[$name]) ? $this->stat[$name] : null;
     }
 
-    /**
-     * SĂ̗vf̃^f[^擾
-     *
-     * @access protected
-     * @return array 
-     */
-    function getStats()
-    {
-        $stat = array();
-        if ($this->exists()) {
-            $name = $this->name;
-            // ^f[^擾
-            $stat = stat($name);
-            for ($i=0; $i<13; $i++) {
-                unset($stat[$i]);
-            }
-        }
-        $this->stat = $stat;
-    }
-
-    /**
-     * vfXg擾
-     *
-     * @access public
-     * @return mixed vfIuWFNgi̔zj
-     */
-    function getList()
-    {
-    }
-
     /**
      * TCY擾
      *
@@ -221,17 +191,6 @@ class SyL_Filesystem
         return isset($this->stat['size']) ? $this->stat['size'] : null;
     }
 
-    /**
-     * TCYifBNg̑St@CTCYj擾
-     *
-     * @access protected
-     * @return int TCY
-     */
-    function getSizeAll()
-    {
-        return $this->getSize();
-    }
-
     /**
      * ŏIXV擾
      *
@@ -240,81 +199,18 @@ class SyL_Filesystem
      */
     function getMtime()
     {
-        if (isset($this->stat['mtime'])) {
-            return $this->stat['mtime'];
-        } else {
-            return null;
-        }
+        return isset($this->stat['mtime']) ? $this->stat['mtime'] : null;
     }
 
     /**
-     * vf݂邩`FbN
-     *
-     * @access protected
-     * @return bool true: ݂Afalse: ݂Ȃ
-     */
-    function exists()
-    {
-        return file_exists($this->name);
-    }
-
-    /**
-     * vfǉ
+     * vf̏LҖ擾
      *
      * @access public
-     * @param object vfIuWFNg
+     * @return string LҖ
      */
-    function add($element)
+    function getOwner()
     {
-    }
-
-    /**
-     * vf폜
-     *
-     * @access public
-     * @return bool true: 폜OKAfalse: 폜G[
-     */
-    function delete()
-    {
-    }
-
-    /**
-     * vfύX
-     *
-     * @access public
-     * @param string Vt@Ci΃pXj
-     * @return bool true: ύXOKAfalse: ύXG[
-     */
-    function rename($new_filename)
-    {
-        if (rename($this->name, $new_filename)) {
-            $this->name = $new_filename;
-            return true;
-        } else {
-            return false;
-        }
-    }
-
-    /**
-     * fBNgKw擾
-     *
-     * @access public
-     * @param int sőKw
-     */
-    function createTree($limit_depth=1)
-    {
-    }
-
-    /**
-     * vf
-     *
-     * @access public
-     * @param string t@C
-     * @param int sőKw
-     */
-    function searchTree($word, $limit_depth=1)
-    {
-        return array();
+        return isset($this->stat['uid']) ? SyL_UtilEnv::getOsUser($this->stat['uid']) : null;
     }
 
     /**
@@ -327,7 +223,13 @@ class SyL_Filesystem
      */
     function getPermission($numeric=true)
     {
-        $perm = fileperms($this->name);
+        $perm = null;
+        if (isset($this->stat['mode'])) {
+            $perm = $this->stat['mode'];
+        } else {
+            return null;
+        }
+
         if ($numeric) {
             return substr(sprintf('%o', $perm), -4);
         } else {
@@ -372,27 +274,153 @@ class SyL_Filesystem
         }
     }
 
+    /**
+     * t@C݂邩`FbN
+     *
+     * @static
+     * @access public 
+     * @param string t@C
+     * @return bool true: ݂Afalse: ݂Ȃ
+     */
+    function exists($file)
+    {
+        if (!file_exists($file)) {
+            return false;
+        }
+        if (is_dir($file)) {
+           return SyL_FilesystemDirectory::exists($file);
+        } else {
+           return SyL_FilesystemFile::exists($file);
+        }
+    }
+
+    /**
+     * t@C폜
+     *
+     * @static
+     * @access public 
+     * @param string t@C
+     * @return bool true: 폜OKAfalse: 폜G[
+     */
+    function remove($file)
+    {
+        if (!file_exists($file)) {
+            return false;
+        }
+
+        if (is_dir($file)) {
+           return SyL_FilesystemDirectory::remove($file);
+        } else {
+           return SyL_FilesystemFile::remove($file);
+        }
+    }
+
+    /**
+     * fBNg쐬
+     *
+     * @static
+     * @access public
+     * @param string fBNgi΃pXj
+     * @param int [h
+     */
+    function createDirectory($dir, $mode=0777)
+    {
+        SyL_FilesystemDirectory::createDirectory($dir, $mode=0777);
+    }
+
+    /**
+     * t@CRs[
+     *
+     * @static
+     * @access public
+     * @param string t@C
+     * @param string Vt@C
+     * @return bool true: ύXOKAfalse: ύXG[
+     */
+    function copy($current_file, $new_file)
+    {
+        return copy($current_file, $new_file);
+    }
+
+    /**
+     * vfύX
+     *
+     * @static
+     * @access public
+     * @param string t@C
+     * @param string Vt@C
+     * @return bool true: ύXOKAfalse: ύXG[
+     */
+    function rename($current_file, $new_file)
+    {
+        return rename($current_file, $new_file);
+    }
+
     /**
      * p[~bVύX
      *
+     * @static
      * @access public
      * @param int p[~bVi8i : 0755j
      * @return bool true: ύXAfalse: G[
      */
-    function changePermission($perm)
+    function changePermission($file, $perm)
     {
-        return chmod($this->name, $perm);
+        return chmod($file, $perm);
     }
 
     /**
-     * vf̏LҖ擾
+     * fBNgt@C擾
      *
+     * @static
      * @access public
-     * @return string LҖ
+     * @param string fBNg
+     * @param bool true: fBNg擾Afalse: fBNg擾Ȃ
+     * @param bool true: t@C擾Afalse: t@C擾Ȃ
+     * @param int sőKw
+     * @return array fBNgt@C
      */
-    function getOwner()
+    function getFiles($file, $is_get_dir=true, $is_get_file=true, $limit_depth=1)
     {
-        return isset($this->stat['uid']) ? SyL_UtilEnv::getOsUser($this->stat['uid']) : null;
+        return SyL_FilesystemDirectory::getFiles($file, $is_get_dir, $is_get_file, $limit_depth);
+    }
+
+    /**
+     * t@C
+     *
+     * @static
+     * @access public
+     * @param string fBNg
+     * @param string t@C
+     * @param bool true: fBNg擾Afalse: fBNg擾Ȃ
+     * @param bool true: t@C擾Afalse: t@C擾Ȃ
+     * @param int sőKw
+     * @return array fBNgt@C
+     */
+    function searchFiles($file, $word, $is_get_dir=true, $is_get_file=true, $limit_depth=1)
+    {
+        return SyL_FilesystemDirectory::searchFiles($file, $word, $is_get_dir, $is_get_file, $limit_depth);
+    }
+
+    /**
+     * TCYifBNg̑St@CTCYj擾
+     *
+     * @static
+     * @access public
+     * @param string fBNg
+     * @param bool true: fBNg̃TCY܂ށAfase: fBNg̃TCY܂܂Ȃ
+     * @return int TCY
+     */
+    function getTotalSize($file, $is_dir_size=false)
+    {
+        if (!file_exists($file)) {
+            return 0;
+        }
+        if (is_dir($file)) {
+           return SyL_FilesystemDirectory::getTotalSize($file, $is_dir_size);
+        } else {
+           return filesize($file);
+        }
     }
 
     /**
@@ -454,7 +482,18 @@ class SyL_Filesystem
         case 'MB': $size /= 1048576; break;
         case 'KB': $size /= 1024; break;
         }
-        return number_format(round($size, $number)) . $suffix;
+        $size = number_format(round($size, $number), $number);
+        $sizes = explode('.', $size, 2);
+        if (isset($sizes[1])) {
+            for ($i=$number-1; $i>=0; $i--) {
+                $tmp = substr($sizes[1], $i, 1);
+                if (!$tmp) {
+                    $sizes[1] = substr($sizes[1], 0, $i);
+                }
+            }
+            $size = $sizes[1] ? "{$sizes[0]}.{$sizes[1]}" : $sizes[0];
+        }
+        return $size;
     }
 
     /**
@@ -482,7 +521,19 @@ class SyL_Filesystem
             $size /= 1024;
             $suffix = 'KB';
         }
-        return number_format(round($size, $number)) . $suffix;
+
+        $size = number_format(round($size, $number), $number);
+        $sizes = explode('.', $size, 2);
+        if (isset($sizes[1])) {
+            for ($i=$number-1; $i>=0; $i--) {
+                $tmp = substr($sizes[1], $i, 1);
+                if (!$tmp) {
+                    $sizes[1] = substr($sizes[1], 0, $i);
+                }
+            }
+            $size = $sizes[1] ? "{$sizes[0]}.{$sizes[1]}" : $sizes[0];
+        }
+        return $size . $suffix;
     } 
 }
 
