@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_XmlRssWriter.php,v 1.4 2008/02/02 14:40:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_XmlRssWriter.php,v 1.5 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once dirname(__FILE__) . '/../SyL_XmlWriter.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_XmlRssWriter.php,v 1.4 2008/02/02 14:40:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_XmlRssWriter.php,v 1.5 2008/09/23 09:06:15 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_XmlRssWriter extends SyL_XmlWriter
@@ -96,6 +96,7 @@ class SyL_XmlRssWriter extends SyL_XmlWriter
      * RSS
      *
      * @access public
+     * @param string XMLС
      */
     function &factory($version='2.0')
     {
@@ -105,7 +106,7 @@ class SyL_XmlRssWriter extends SyL_XmlWriter
             trigger_error("[SyL error] Rss version not supported ({$version})", E_USER_ERROR);
         }
         include_once $include_file;
-        $writer =& new $classname();
+        $writer = new $classname();
         return $writer;
     }
 
@@ -174,12 +175,13 @@ class SyL_XmlRssWriter extends SyL_XmlWriter
      * RSS
      * 
      * @access public
+     * @param bool ѡåԤ
      * @return string RSSǡ
      */
     function create($parser_check=false)
     {
         $this->isEol(true);
-        $this->addDeclaration();
+        $this->setDeclaration();
         // XML
         $this->createXml();
         return parent::create($parser_check);
@@ -188,7 +190,7 @@ class SyL_XmlRssWriter extends SyL_XmlWriter
     /**
      * RSS XML
      * 
-     * @access public
+     * @access protected
      */
     function createXml()
     {
